==> twilio_messaging_sftp-0.0.16.tar.gz: twilio_messaging_sftp-0.0.16/src/sftp_client/httpClient.py <==
import logging
from queue import Queue
from threading import Thread
from time import time
from twilio.rest import Client
import multiprocessing

logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')

logger = logging.getLogger(__name__)


class MessageWorker(Thread):

    def __init__(self, queue):
        Thread.__init__(self)
        self.queue = queue
        logger.debug('Created {}'.format(self.name))

    def run(self):
        while True:
            # Get the work from the queue and expand the tuple
            client, index, msg, result = self.queue.get()
            try:
                logger.info('{}: Sending message ({})'.format(self.name,msg))
                msg.all_params['response'] = client.send_message(msg)
            except Exception as error:
                logger.error('{}: Error {} sending message ({})'.format(self.name,error,msg))
                msg.all_params['response'] = str(error)
            finally:
                result[index] = msg.all_params
                self.queue.task_done()
                self.queue



class MessageClient:
    """A wrapper client to talk to Twilio Messaging Services."""

    def __init__(self, acct_sid, auth_token):
        """Initialize client with appropriate twilio authentication."""
        self.account_sid = acct_sid
        self.auth_token = auth_token
        self.client = Client(self.account_sid, self.auth_token)

    def response_list_to_csv_str(self,responses):
        csv_str = ""
        for response in responses:
            line = ",".join(response.values())
            csv_str+=line+'\n'
        return csv_str

    def send_message(self, query_params):

        message = self.client.messages.create(
            body=query_params.body,
            from_=query_params.from_,
            media_url=query_params.media_url,
            to=query_params.to
        )
        return message.sid

    def enqueue_messages(self, messages):

        ts = time()

        responses = [None]*len(messages)

        # Create a queue to communicate with the worker threads
        queue = Queue()

        # Create 2 worker threads for each core
        for x in range(multiprocessing.cpu_count() * 2):
            worker = MessageWorker(queue)
            # Setting daemon to True will let the main thread exit even though the workers are blocking
            worker.daemon = True
            worker.start()

        # Put the tasks into the queue as a tuple
        for index,msg in enumerate(messages):
            logger.info('Queueing message ({})'.format(msg))
            queue.put((self,index,msg,responses))

        # Causes the main thread to wait for the queue to finish processing all the tasks
        queue.join()
        logging.info('Took %s seconds', time() - ts)

        return self.response_list_to_csv_str(responses)

==> twilio_messaging_sftp-0.0.17.tar.gz: twilio_messaging_sftp-0.0.17/src/sftp_client/httpClient.py <==
import logging
from queue import Queue
from threading import Thread
from time import time
from twilio.rest import Client
import multiprocessing
import csv

logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')

logger = logging.getLogger(__name__)


class MessageWorker(Thread):

    def __init__(self, queue):
        Thread.__init__(self)
        self.queue = queue
        logger.debug('Created {}'.format(self.name))

    def run(self):
        while True:
            # Get the work from the queue and expand the tuple
            client, index, msg, result = self.queue.get()
            try:
                logger.info('{}: Sending message ({})'.format(self.name,msg))
                msg.all_params['response'] = client.send_message(msg)
            except Exception as error:
                logger.error('{}: Error {} sending message ({})'.format(self.name,error,msg))
                msg.all_params['response'] = str(error)
            finally:
                result[index] = msg.all_params
                self.queue.task_done()
                self.queue



class MessageClient:
    """A wrapper client to talk to Twilio Messaging Services."""

    def __init__(self, acct_sid, auth_token):
        """Initialize client with appropriate twilio authentication."""
        self.account_sid = acct_sid
        self.auth_token = auth_token
        self.client = Client(self.account_sid, self.auth_token)

    def response_list_to_csv_file(self,responses,filename):
        with open(filename, 'w') as csvfile:
            writer = csv.DictWriter(csvfile, fieldnames=responses[0].keys())
            writer.writeheader()
            for response in responses:
                print(response.keys())
                writer.writerow(response)

    def send_message(self, query_params):

        message = self.client.messages.create(
            body=query_params.body,
            from_=query_params.from_,
            media_url=query_params.media_url,
            to=query_params.to
        )
        return ("MessageSid: {} / Status: {} / Error: {} / ErrorCode: {}".format(message.sid,message.status,message.error_message,message.error_code))

    def enqueue_messages(self, messages, output_filename):

        ts = time()

        responses = [None]*len(messages)

        # Create a queue to communicate with the worker threads
        queue = Queue()

        # Create 2 worker threads for each core
        for x in range(multiprocessing.cpu_count() * 2):
            worker = MessageWorker(queue)
            # Setting daemon to True will let the main thread exit even though the workers are blocking
            worker.daemon = True
            worker.start()

        # Put the tasks into the queue as a tuple
        for index,msg in enumerate(messages):
            logger.info('Queueing message ({})'.format(msg))
            queue.put((self,index,msg,responses))

        # Causes the main thread to wait for the queue to finish processing all the tasks
        queue.join()
        logging.info('Took %s seconds', time() - ts)
        print(responses)
        self.response_list_to_csv_file(responses,output_filename)
        return responses
